==> zurmo-1.0.20p1.tgz: zurmo/app/protected/modules/import/forms/CurrencyRateToBaseModelAttributeMappingRuleForm.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * This form is used for mapping a currencyValue attribute.  This form allows the user to select the rate to base
     * of the importing values. The form will default with a rate to base of 1.
     * @see CurrencyIdModelAttributeMappingRuleForm
     * @see CurrencyValueAttributeImportRules
     */
    class CurrencyRateToBaseModelAttributeMappingRuleForm extends ModelAttributeMappingRuleForm
    {
        public $rateToBase;

        public function __construct($modelClassName, $modelAttributeName)
        {
            parent::__construct($modelClassName, $modelAttributeName);
            $this->rateToBase = 1;
        }

        public function rules()
        {
            return array(
                array('rateToBase',  'required'),
                array('rateToBase',  'type', 'type' => 'float'),
            );
        }

        public function attributeLabels()
        {
            return array('rateToBase'   => Yii::t('Default', 'Rate To Base'));
        }

        public static function getAttributeName()
        {
            return 'rateToBase';
        }
    }
?>

==> zurmo-1.1.31.tgz: zurmo/app/protected/modules/import/forms/CurrencyRateToBaseModelAttributeMappingRuleForm.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * This form is used for mapping a currencyValue attribute.  This form allows the user to select the rate to base
     * of the importing values. The form will default with a rate to base of 1.
     * @see CurrencyIdModelAttributeMappingRuleForm
     * @see CurrencyValueAttributeImportRules
     */
    class CurrencyRateToBaseModelAttributeMappingRuleForm extends ModelAttributeMappingRuleForm
    {
        public $rateToBase;

        public function __construct($modelClassName, $modelAttributeName)
        {
            parent::__construct($modelClassName, $modelAttributeName);
            $this->rateToBase = 1;
        }

        public function rules()
        {
            return array(
                array('rateToBase',  'required'),
                array('rateToBase',  'type', 'type' => 'float'),
            );
        }

        public function attributeLabels()
        {
            return array('rateToBase'   => Zurmo::t('ImportModule', 'Rate To Base'));
        }

        public static function getAttributeName()
        {
            return 'rateToBase';
        }
    }
?>
